@@ -5,7 +5,7 @@ The module contains a single class, `Perturbations`, which wraps almost all the
 functionality of `hmf` in an easy-to-use way.
 '''
 
-version = '1.3.0'
+version = '1.3.1'
 
 ###############################################################################
 # Some Imports
@@ -16,10 +16,8 @@ import numpy as np
 from numpy import sin, cos, tan, abs, arctan, arccos, arcsin, exp
 import copy
 
-# from scitools.std import sin,cos,tan,abs,arctan,arccos,arcsin #Must be in this form to work for some reason.
 from cosmolopy import distance as cd
 from cosmolopy import density as cden
-# import cosmography
 from cosmo import Cosmology
 import tools
 from fitting_functions import Fits
@@ -1225,7 +1223,7 @@ class Perturbations(object):
     @property
     def nltm(self):
         """
-        Lower cumulative mass function, , ``len=len(M)`` [units :math:`h^3 Mpc^{-3}`]
+        Lower cumulative mass function, ``len=len(M)`` [units :math:`h^3 Mpc^{-3}`]
         """
         try:
             return self.__nltm
